@@ -59,13 +59,31 @@ from ._api import (
     get_addon_url,
     download_addon_private_file,
 
+    get_installers,
+    create_installer,
+    update_installer,
+    delete_installer,
+    download_installer,
+    upload_installer,
+
     get_dependencies_info,
     update_dependency_info,
+    get_dependency_packages,
+    create_dependency_package,
+    update_dependency_package,
+    delete_dependency_package,
 
     download_dependency_package,
     upload_dependency_package,
-    delete_dependency_package,
 
+    get_bundles,
+    create_bundle,
+    update_bundle,
+    delete_bundle,
+
+    get_info,
+    get_server_version,
+    get_server_version_tuple,
     get_user,
     get_users,
 
@@ -87,34 +105,39 @@ from ._api import (
     get_addons_project_settings,
     get_addons_settings,
 
+    get_project_names,
     get_projects,
     get_project,
     create_project,
+    update_project,
     delete_project,
 
     get_folder_by_id,
     get_folder_by_name,
     get_folder_by_path,
     get_folders,
+    get_folders_hierarchy,
 
     get_tasks,
 
-    get_folder_ids_with_subsets,
-    get_subset_by_id,
-    get_subset_by_name,
-    get_subsets,
-    get_subset_families,
+    get_folder_ids_with_products,
+    get_product_by_id,
+    get_product_by_name,
+    get_products,
+    get_product_types,
+    get_project_product_types,
+    get_product_type_names,
 
     get_version_by_id,
     get_version_by_name,
     version_is_latest,
     get_versions,
-    get_hero_version_by_subset_id,
+    get_hero_version_by_product_id,
     get_hero_version_by_id,
     get_hero_versions,
     get_last_versions,
-    get_last_version_by_subset_id,
-    get_last_version_by_subset_name,
+    get_last_version_by_product_id,
+    get_last_version_by_product_name,
     get_representation_by_id,
     get_representation_by_name,
     get_representations,
@@ -122,6 +145,10 @@ from ._api import (
     get_representation_parents,
     get_repre_ids_by_context_filters,
 
+    get_workfiles_info,
+    get_workfile_info,
+    get_workfile_info_by_id,
+
     get_thumbnail,
     get_folder_thumbnail,
     get_version_thumbnail,
@@ -143,8 +170,8 @@ from ._api import (
     get_folders_links,
     get_task_links,
     get_tasks_links,
-    get_subset_links,
-    get_subsets_links,
+    get_product_links,
+    get_products_links,
     get_version_links,
     get_versions_links,
     get_representations_links,
@@ -212,13 +239,31 @@ __all__ = (
     "get_addon_url",
     "download_addon_private_file",
 
+    "get_installers",
+    "create_installer",
+    "update_installer",
+    "delete_installer",
+    "download_installer",
+    "upload_installer",
+
     "get_dependencies_info",
     "update_dependency_info",
+    "get_dependency_packages",
+    "create_dependency_package",
+    "update_dependency_package",
+    "delete_dependency_package",
 
     "download_dependency_package",
     "upload_dependency_package",
-    "delete_dependency_package",
 
+    "get_bundles",
+    "create_bundle",
+    "update_bundle",
+    "delete_bundle",
+
+    "get_info",
+    "get_server_version",
+    "get_server_version_tuple",
     "get_user",
     "get_users",
 
@@ -239,9 +284,11 @@ __all__ = (
     "get_addons_project_settings",
     "get_addons_settings",
 
+    "get_project_names",
     "get_projects",
     "get_project",
     "create_project",
+    "update_project",
     "delete_project",
 
     "get_folder_by_id",
@@ -251,22 +298,24 @@ __all__ = (
 
     "get_tasks",
 
-    "get_folder_ids_with_subsets",
-    "get_subset_by_id",
-    "get_subset_by_name",
-    "get_subsets",
-    "get_subset_families",
+    "get_folder_ids_with_products",
+    "get_product_by_id",
+    "get_product_by_name",
+    "get_products",
+    "get_product_types",
+    "get_project_product_types",
+    "get_product_type_names",
 
     "get_version_by_id",
     "get_version_by_name",
     "version_is_latest",
     "get_versions",
-    "get_hero_version_by_subset_id",
+    "get_hero_version_by_product_id",
     "get_hero_version_by_id",
     "get_hero_versions",
     "get_last_versions",
-    "get_last_version_by_subset_id",
-    "get_last_version_by_subset_name",
+    "get_last_version_by_product_id",
+    "get_last_version_by_product_name",
     "get_representation_by_id",
     "get_representation_by_name",
     "get_representations",
@@ -274,6 +323,10 @@ __all__ = (
     "get_representation_parents",
     "get_repre_ids_by_context_filters",
 
+    "get_workfiles_info",
+    "get_workfile_info",
+    "get_workfile_info_by_id",
+
     "get_thumbnail",
     "get_folder_thumbnail",
     "get_version_thumbnail",
@@ -295,8 +348,8 @@ __all__ = (
     "get_folders_links",
     "get_task_links",
     "get_tasks_links",
-    "get_subset_links",
-    "get_subsets_links",
+    "get_product_links",
+    "get_products_links",
     "get_version_links",
     "get_versions_links",
     "get_representations_links",
